# eric7.Plugins.VcsPlugins.vcsMercurial.GpgExtension.ProjectHelper

Module implementing the gpg extension project helper.

### Global Attributes

None

### Classes

GpgProjectHelper | Class implementing the gpg extension project helper.

### Functions

None

## GpgProjectHelper

Class implementing the gpg extension project helper.

### Derived from

HgExtensionProjectHelper

### Class Attributes

None

### Class Methods

None

### Methods

GpgProjectHelper | Constructor
__hgGpgSign | Private slot used to sign a revision.
__hgGpgSignatures | Private slot used to list all signed changesets.
__hgGpgVerifySignatures | Private slot used to verify the signatures of a revision.
initActions | Public method to generate the action objects.
initMenu | Public method to generate the extension menu.
menuTitle | Public method to get the menu title.

### Static Methods

None

#### GpgProjectHelper (Constructor)

GpgProjectHelper()

Constructor

#### GpgProjectHelper.__hgGpgSign

__hgGpgSign()

Private slot used to sign a revision.

#### GpgProjectHelper.__hgGpgSignatures

__hgGpgSignatures()

Private slot used to list all signed changesets.

#### GpgProjectHelper.__hgGpgVerifySignatures

__hgGpgVerifySignatures()

Private slot used to verify the signatures of a revision.

#### GpgProjectHelper.initActions

initActions()

Public method to generate the action objects.

#### GpgProjectHelper.initMenu

initMenu(mainMenu)

Public method to generate the extension menu.

mainMenu (QMenu)
  reference to the main menu

Return:
  populated menu

Return Type:
  QMenu

#### GpgProjectHelper.menuTitle

menuTitle()

Public method to get the menu title.

Return:
  title of the menu

Return Type:
  str

Up